@@ -29,9 +29,6 @@
   void
 _Draw_Structure( cairo_t *cr )
 {
-  /* Abort if xnec2c may be quit by user */
-  if( isFlagSet(MAIN_QUIT) ) return;
-
   /* Clear drawingarea */
   cairo_set_source_rgb( cr, BLACK );
   cairo_rectangle(
@@ -379,8 +376,8 @@ Draw_Wire_Segments( cairo_t *cr, Segment_t *segm, gint nseg )
     static double cmax; /* Max of seg current/charge */
     /* To color structure segs */
     double red = 0.0, grn = 0.0, blu = 0.0;
-    char label[11];
-    size_t s = sizeof( label );
+    char label[16];
+    size_t s = sizeof( label )-1;
 
     /* Loop over all wire segs, find max current/charge */
     if( crnt.newer )
@@ -393,7 +390,7 @@ Draw_Wire_Segments( cairo_t *cr, Segment_t *segm, gint nseg )
           cmag[idx] = (double)cabs( crnt.cur[idx] );
         else
           /* Calculate segment charge density */
-          cmag[idx] = (double)cabs( cmplx(crnt.bii[idx], crnt.bir[idx]) );
+          cmag[idx] = (double)cabs( cmplx(crnt.bir[idx], crnt.bii[idx]) );
 
         /* Find max current/charge magnitude */
         if( cmag[idx] > cmax )
@@ -709,10 +706,10 @@ Show_Viewer_Gain(
       isFlagSet(DRAW_GAIN)     ||
       isFlagSet(FREQ_LOOP_RUNNING) )
   {
-    char txt[8];
+    char txt[16];
     if( isFlagSet(ENABLE_RDPAT) && (calc_data.freq_step >= 0) )
     {
-      snprintf( txt, sizeof(txt), "%7.2f", Viewer_Gain(proj_params, calc_data.freq_step) );
+      snprintf( txt, sizeof(txt)-1, "%.2f", Viewer_Gain(proj_params, calc_data.freq_step) );
       gtk_entry_set_text( GTK_ENTRY(Builder_Get_Object(builder, widget)), txt );
     }
   }
