@@ -417,7 +417,7 @@ Child_Process( int num_child )
     switch( Fork_Command(cmnd) )
     {
       case MATHLIB:
-        retval = Read_Pipe( num_child,
+        Read_Pipe( num_child,
 			(char*)&rc_config.mathlib_batch_idx,
 			sizeof(rc_config.mathlib_batch_idx), FALSE );
 
@@ -432,7 +432,7 @@ Child_Process( int num_child )
 
       case INFILE: /* Read input file */
         retval = Read_Pipe( num_child, rc_config.input_file, sizeof(rc_config.input_file), FALSE );
-        rc_config.input_file[retval] = '\0';
+        rc_config.input_file[retval-1] = '\0';
         Child_Input_File();
         break;
 
